<?php
/*
Plugin Name: Jon's Plugin
Plugin URI: http://jonathandesrosiers.com
Description: Jon's plugin created for WordCamp Providence 2014
Version: 1.0
Author: desrosj
Author URI: http://jonathandesrosiers.com
License: GPLv2 or later
*/

/*
 * Register our custom post type and taxonomy.
 */
function wcpvd_init() {
	//Custom Post Type Arguments
	$args = array(
		'labels' => array(
			'name' => 'Movies',
			'singular_name' => 'Movie',
			'menu_name' => 'Movies',
			'add_new' => 'Add New',
			'add_new_item' => 'Add New Movie',
			'edit_item' => 'Edit Movie',
			'new_item' => 'New Movie',
			'all_items' => 'All Movies',
			'view_item' => 'View Movie',
			'search_items' => 'Search Movies',

		),
		'public' => true,
		'hierarchical' => false,
		'supports' => array( 'title','editor','thumbnail','comments' ),
		'has_archive' => true,
		'show_in_nav_menus' => true,
		'rewrite' => array( 'slug' => 'movies' ),
	);
	//Register our custom post type
	register_post_type( 'wcpvd_movie', $args );

	//Custom Taxonomy arguments
	$taxonomy_args = array(
		'labels' => array(
			'name' => 'Genre',
			'singular_name' => 'Genre',
			'search_items' => 'Search Genres',
			'all_items' => 'All Genres',
			'parent_item' => 'Parent Genre',
			'parent_item_colon' => 'Parent Genre:',
			'edit_item' => 'Edit Genre',
			'update_item' => 'Update Genre',
			'add_new_item' => 'Add New Genre',
			'new_item_name' => 'New Genre Name',
			'menu_name' => 'Genres',
		),
		'hierarchical' => true,
		'show_ui' => true,
		'query_var' => true,
		'rewrite' => array( 'slug' => 'genres' ),
		'show_admin_column' => true,
	);
	//Register custom taxonomy
	register_taxonomy( 'wcpvd_genre', 'wcpvd_movie', $taxonomy_args );
}
add_action( 'init', 'wcpvd_init' );

/*
 * Filter our post classes to includ a taxonomt
 */
function wcpvd_post_class( $classes, $class, $post_id ) {
	//If the current post is not a movie, don't do anything
	if ( 'wcpvd_movie' != get_post_type( $post_id ) )
		return $classes;

	//Get all of our custom taxonomy terms assigned to this post
	$genres = get_the_terms( $post_id, 'wcpvd_genre' );

	//If there are none, or there was an error, bail
	if ( empty( $genres ) || is_wp_error( $genres ) )
		return $classes;

	//Add a new class for each term this post has
	foreach ( $genres as $genre )
		$classes[] = 'genre-' . $genre->slug;

	//Return the classes
	return $classes;
}
add_filter( 'post_class', 'wcpvd_post_class', 10, 3 );

/*
 * Add our custom post meta box
 */
function wcpvd_movie_add_meta_boxes() {
	add_meta_box( 'wcpvd_movie_info', 'Movie Info', 'wcpvd_movie_info_meta_box', 'wcpvd_movie', 'side', 'high' );
}
add_action( 'add_meta_boxes', 'wcpvd_movie_add_meta_boxes' );

/*
 * Display our post meta box in the admin
 */
function wcpvd_movie_info_meta_box( $post ) {
	$director = get_post_meta( $post->ID, '_wcpvd_director', true );
	?>
	<p>
		<label for="wcpvd_director"><strong>Director:</strong></label>
		<input type="text" name="wcpvd_director" class="widefat" value="<?php echo esc_attr( $director ); ?>" />
	</p>
	<?php
}

/*
 * Save our custom post meta
 */
function wcpvd_save_post( $post_id ) {
	//Skip revisions and autosaves
	if ( wp_is_post_revision( $post_id ) || ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) )
		return;

	//Users should have the ability to edit listings.
	if ( ! current_user_can( 'edit_post', $post_id ) )
		return;

	//Make sure that our field is present
	if ( isset( $_POST['wcpvd_director'] ) ) {

		//Handle and save our post meta
		if ( empty( $_POST['wcpvd_director'] ) ) {
			delete_post_meta( $post_id, '_wcpvd_director' );
		} else {
			//Sanitize our data to prevent bad stuff
			$director = sanitize_text_field( $_POST['wcpvd_director'] );
			update_post_meta( $post_id, '_wcpvd_director', $director );
		}

	}
}
add_action( 'save_post', 'wcpvd_save_post' );

/*
 * Filter post content to prepend the movie director
 */
function wcpvd_the_content( $post_content ) {

	//Only update movies
	if ( 'wcpvd_movie' != get_post_type() )
		return $post_content;

	$director = get_post_meta( get_the_ID(), '_wcpvd_director', true );

	//If the movie does not have a director, don't do anything
	if ( empty( $director ) )
		return $post_content;

	//Return our new post content
	return '<h4 class="movie-director">' . sanitize_text_field( $director ) . '</h4>' . $post_content;
}

/*
 * Filter the post title to append the movie director
 */
function wcpvd_the_title( $post_title, $post_id ) {
	//Only update movies
	if ( 'wcpvd_movie' != get_post_type( $post_id ) )
		return $post_title;

	$director = get_post_meta( $post_id, '_wcpvd_director', true );

	//If the movie does not have a director, don't do anything
	if ( empty( $director ) )
		return $post_title;

	//Return our new post title
	return $post_title . ' - ' . sanitize_text_field( $director );
}

/*
 * Add the appropriate filter based on the setting value. Default to the title
 */
if ( 'post_content' == get_option( 'wcpvd_director_display' ) )
	add_filter( 'the_content', 'wcpvd_the_content', 20 );
else
	add_filter( 'the_title', 'wcpvd_the_title', 20, 2 );

/*
 * Register and add a custom setting
 */
function wcpvd_admin_init() {
	//Register our setting so it saves
	register_setting( 'reading', 'wcpvd_director_display' );

	//Add our settings field
	add_settings_field( 'wcpvd_director_display', 'Director Display', 'wcpvd_director_display_field', 'reading' );
}
add_action( 'admin_init', 'wcpvd_admin_init' );

/*
 * Display our custom setting field
 */
function wcpvd_director_display_field() {
	$option = get_option( 'wcpvd_director_display' );
	?>
	<select name="wcpvd_director_display">
		<option value="post_title" <?php selected( 'post_title', $option ); ?>>After Post Title</option>
		<option value="post_content" <?php selected( 'post_content', $option ); ?>>Before Post Content</option>
	</select>
	<?php
}